package org.kantega.jexmec;

/*
 * Copyright 2009 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.Locale;

/**
 * Abstract Plugin implementation.
 */
public abstract class AbstractPlugin implements Plugin {
    /**
     * The globally unique plugin id.
     */
    private String pluginUid;

    /**
     * The human readable name of this plugin.
     */
    private String pluginName;

    /**
     * The human readable description of this plugin.
     */
    private String pluginDescription;

    /**
     * This constructor creates a plugin with a given plugin uid.
     * @param pluginUid the pluginUid of this plugin
     */
    protected AbstractPlugin(final String pluginUid) {
        this.pluginUid = pluginUid;
    }

    /**
     * {@inheritDoc}
     */
    public String getPluginUid() {
        return pluginUid;
    }

    /**
     * {@inheritDoc}
     */
    public String getPluginName(final Locale locale) {
        return pluginName;
    }

    /**
     * Set the human readable name of this plugin.
     * @param pluginName the human readable name
     */
    public void setPluginName(final String pluginName) {
        this.pluginName = pluginName;
    }

    /**
     * {@inheritDoc}
     */
    public String getPluginDescription(final Locale locale) {
        return pluginDescription;
    }

    /**
     * Sets the human readable description of this plugin
     * @param pluginDescription the human readable description
     */
    public void setPluginDescription(final String pluginDescription) {
        this.pluginDescription = pluginDescription;
    }

}
