package org.kantega.jexmec;

/*
 * Copyright 2009 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.List;
import java.util.ArrayList;
import java.util.Enumeration;
import java.net.URL;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.io.InputStream;

/**
 */
public class DefaultClassLocator<T extends Class> implements ClassLocator<T> {
    private String servicesFile;

    public DefaultClassLocator(String servicesFile) {
        this.servicesFile = servicesFile;
    }


    public DefaultClassLocator(Class pluginClass, String filename) {
        this("META-INF/services/" +pluginClass.getName() +"/" + filename);
    }
    
    public List<T> locateClasses(ClassLoader classLoader) {
        List<T> classes = new ArrayList<T>();

        try {
            Enumeration<URL> resources = classLoader.getResources(servicesFile);
            while (resources.hasMoreElements()) {
                final URL url = resources.nextElement();

                InputStream inputStream = null;
                InputStreamReader inputStreamReader = null;
                BufferedReader bufferedReader = null;

                try {
                    inputStream = url.openStream();
                    inputStreamReader = new InputStreamReader(inputStream, "utf-8");
                    bufferedReader = new BufferedReader(inputStreamReader);

                    String className;
                    while ((className = bufferedReader.readLine()) != null) {
                        className = className.trim();
                        if (className.length() > 0) {

                            try {
                                @SuppressWarnings("unchecked")
                                T clazz = (T) classLoader.loadClass(className);
                                classes.add(clazz);
                            } catch (ClassNotFoundException e) {
                                throw new PluginClassNotFoundException("Plugin descriptor " +url +" specifies a class that can't be found: " + className, className, e);
                            }

                        }
                    }
                } finally {
                    if (bufferedReader != null) {
                        bufferedReader.close();
                    }
                    if (inputStreamReader != null) {
                        inputStreamReader.close();
                    }
                    if (inputStream != null) {
                        inputStream.close();
                    }
                }
            }
            return classes;
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }
}
