package org.kantega.jexmec;

/*
 * Copyright 2009 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.Locale;

/**
 * Interface representing a component providing extended functionality to an application.
 * This interface only contains generic meta-information. Application specific methods will be found
 * in subinterfaces of this interface.
 *
 */
public interface Plugin {
    /**
     * Return a globally unique string identifying this plugin.
     * Will typically be in the form of a revese internet domain name followed by organization specific
     * identification, such as <code>com.example.app.plugins.myplugin</code>
     * @return the globally unique plugin id
     */
    String getPluginUid();

    /**
     * Returns a human readable name for this plugin, possibly localizing it.
     * @param locale the locale to localize to
     * @return the name of the plugin
     */
    String getPluginName(Locale locale);

    /**
     * Returns a human readable short description for this plugin, possibly localizing it.
     * This should describe what this plugin provides.
     * @param locale the locale to localize to
     * @return the plugin description
     */
    String getPluginDescription(Locale locale);
}
