package org.kantega.jexmec;

/*
 * Copyright 2009 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * This marker interface is designed to be extended by application API designers.
 * Methods in the child interface must have one getter method for each
 * service interface that the application wishes to make available to the
 * application's plugins.
 *
 * An application implementation of this interface might look like this:
 *
 * <pre>
 * public interface AppServices extends Services {
 *
 *   UserDao getUserDaoService();
 *
 * }
 * </pre>
 *
 * This will make the {@code UserDao} interface available as a service.
 *
 * If you have multiple services of the same type, you need to qualify
 * them by name. This is done by adding an enum parameter to the getter. The
 * enum should have one name for each service name that you wish to expose:
 *
 *
 * <pre>
 * public interface AppServices extends Services {
 *
 *   DataSource getUserDaoService(DataSourceNames names);
 *
 *   enum DataSourceNames {userDataSource, orderDataSource}
 * }
 * </pre>
 */
public interface Services {
    
}
