package org.kantega.jexmec;

import java.util.Set;
import java.util.Collections;
import java.util.Map;
import java.util.HashMap;

/**
 * Service locator for
 */
public class StaticServiceLocator implements ServiceLocator {

    private final Map<ServiceKey, Object> services;

    public StaticServiceLocator() {
        this(Collections.<ServiceKey, Object>emptyMap());
    }

    public StaticServiceLocator(Map<ServiceKey, Object> services) {
        this.services = new HashMap<ServiceKey, Object>(services);
    }

    public Set<ServiceKey> getServiceKeys() {
        return services.keySet();
    }

    public <T> T lookupService(Class<T> serviceClass) {
        return lookupService(serviceClass, null);
    }
    public <T> T lookupService(Class<T> serviceClass, String serviceName) {
        return serviceClass.cast(services.get(new ServiceKey(serviceClass, serviceName)));
    }

    public <T> void addService(Class<T> serviceClass,  T serviceImplementation) {
        addService(serviceClass, null, serviceImplementation);
    }
    public <T> void addService(Class<T> serviceClass, String serviceName, T serviceImplementation) {
        this.services.put(new ServiceKey(serviceClass, serviceName), serviceImplementation);
    }
}
