package org.kantega.jexmec.simple;

/*
 * Copyright 2009 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.kantega.jexmec.ClassLoaderListener;
import org.kantega.jexmec.ClassLoaderStrategy;

import java.util.List;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Arrays;

/**
 * ClassLoaderStrategy using a static list of classloaders.
 */
public class SimpleClassLoaderStrategy implements ClassLoaderStrategy {
    private List<ClassLoader> classLoaders = new ArrayList<ClassLoader>();

    private final List<ClassLoaderListener> classLoaderListeners = Collections.synchronizedList(new ArrayList<ClassLoaderListener>());

    public SimpleClassLoaderStrategy(List<ClassLoader> classLoaders) {
        this.classLoaders.addAll(classLoaders);
    }

    public SimpleClassLoaderStrategy(ClassLoader... classLoaders) {
        this.classLoaders.addAll(Arrays.asList(classLoaders));
    }

    public void addClassLoaderListener(ClassLoaderListener listener) {
        classLoaderListeners.add(listener);
    }

    public void removeClassLoaderListener(ClassLoaderListener listener) {
        classLoaderListeners.remove(listener);
    }

    public void addClassLoader(ClassLoader... classLoaders) {
        this.classLoaders.addAll(Arrays.asList(classLoaders));
    }

    public void start() {
        for (ClassLoader loader : classLoaders) {
            for (ClassLoaderListener listener : classLoaderListeners) {
                listener.classLoaderAdded(loader);
            }
        }
    }

    public void stop() {
        for (ClassLoader loader : classLoaders) {
            for (ClassLoaderListener listener : classLoaderListeners) {
                listener.classLoaderRemoved(loader);
            }
        }
    }

    public List<ClassLoader> getClassLoaders() {
        return classLoaders;
    }
}
